summaryrefslogtreecommitdiffstats
path: root/kjsembed/jsopaqueproxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/jsopaqueproxy.h')
-rw-r--r--kjsembed/jsopaqueproxy.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/kjsembed/jsopaqueproxy.h b/kjsembed/jsopaqueproxy.h
index f29458cf..e5a4c1f0 100644
--- a/kjsembed/jsopaqueproxy.h
+++ b/kjsembed/jsopaqueproxy.h
@@ -22,8 +22,8 @@
#ifndef KJSEMBEDJSOPAQUEPROXY_H
#define KJSEMBEDJSOPAQUEPROXY_H
-#include <qcstring.h>
-#include <qevent.h>
+#include <tqcstring.h>
+#include <tqevent.h>
#include <kjs/object.h>
#include <kjsembed/jsproxy.h>
@@ -57,16 +57,16 @@ public:
}
/** Creates an opaque proxy. */
- JSOpaqueProxy( QTextStream *ts );
+ JSOpaqueProxy( TQTextStream *ts );
/** Creates an opaque proxy. */
- JSOpaqueProxy( const QEvent *ev );
+ JSOpaqueProxy( const TQEvent *ev );
/** Cleans up. */
virtual ~JSOpaqueProxy();
/** Returns the type of the wrapped object.*/
- QString typeName() const;
+ TQString typeName() const;
/** Sets the value of the proxy and its type. */
template<typename T>
@@ -79,11 +79,11 @@ public:
ptrtype = ptype ? ptype : "void";
}
- /** Sets the value of the proxy to a QTextStream. */
- void setValue( QTextStream *ts );
+ /** Sets the value of the proxy to a TQTextStream. */
+ void setValue( TQTextStream *ts );
- /** Sets the value of the proxy to a QEvent. */
- void setValue( const QEvent *ev );
+ /** Sets the value of the proxy to a TQEvent. */
+ void setValue( const TQEvent *ev );
/** Returns the proxy value as a pointer. */
template<typename T>
@@ -98,12 +98,12 @@ public:
bool inherits( const char *clazz );
/**
* Returns the QTextStream stored in the proxy. If proxy does not contain
* a value of type QTextStream then 0 is returned.
*/
- QTextStream *toTextStream();
+ TQTextStream *toTextStream();
- const QEvent *toEvent();
+ const TQEvent *toEvent();
/** Adds the bindings for the opaque proxy to the specified js object. */
virtual void addBindings( KJS::ExecState *state, KJS::Object &object );
@@ -113,9 +113,9 @@ public:
private:
- QTextStream *textstream;
- const QEvent *event;
- QCString ptrtype;
+ TQTextStream *textstream;
+ const TQEvent *event;
+ TQCString ptrtype;
class JSOpaqueProxyPrivate *d;
@@ -98,12 +98,12 @@ public:
bool inherits( const char *clazz );
/**
- * Returns the QTextStream stored in the proxy. If proxy does not contain
- * a value of type QTextStream then 0 is returned.
+ * Returns the TQTextStream stored in the proxy. If proxy does not contain
+ * a value of type TQTextStream then 0 is returned.
*/